"""
This file stores the package version.
"""

# SPDX-FileCopyrightText: 2023-present Remco <remco@educationwarehouse.nl>
#
# SPDX-License-Identifier: MIT

# __version__ = "0.10.4"
__version__ = "1.0.0a16"
